@@ -37,7 +37,7 @@ use base qw{ PPIx::Regexp::Token::Reference };
 use Carp qw{ confess };
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL RE_CAPTURE_NAME };
 
-our $VERSION = '0.021_11';
+our $VERSION = '0.028_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -73,7 +73,7 @@ my @recognize = (	# recognition used internally
 	}smx, { is_named => 0 }, ],
     [
 	qr{ \A \\ (?:		# named
-	    g \{ ( @{[ RE_CAPTURE_NAME ]} ) \} |
+	    g [{] ( @{[ RE_CAPTURE_NAME ]} ) [}] |
 	    k (?: \< ( @{[ RE_CAPTURE_NAME ]} ) \> |	# named with angles
 		' ( @{[ RE_CAPTURE_NAME ]} ) ' )	#   or quotes
 	)
@@ -134,7 +134,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
