@@ -13,7 +13,8 @@ PPIx::Regexp::Token::CharClass::POSIX - Represent a POSIX character class
 C<PPIx::Regexp::Token::CharClass::POSIX> is a
 L<PPIx::Regexp::Token::CharClass|PPIx::Regexp::Token::CharClass>.
 
-C<PPIx::Regexp::Token::CharClass::POSIX> has no descendants.
+C<PPIx::Regexp::Token::CharClass::POSIX> is the parent of
+L<PPIx::Regexp::Token::CharClass::POSIX::Unknown|PPIx::Regexp::Token::CharClass::POSIX::Unknown>.
 
 =head1 DESCRIPTION
 
@@ -23,7 +24,7 @@ recognized within a character class.
 Note that collating symbols (e.g. C<[.ch.]>) and equivalence classes
 (e.g. C<[=a=]>) are valid in the POSIX standard, but are not valid in
 Perl regular expressions. These end up being represented by
-L<PPIx::Regexp::Token::CharClass::Posix::Unknown|PPIx::Regexp::Token::CharClass::Posix::Unknown>,
+L<PPIx::Regexp::Token::CharClass::POSIX::Unknown|PPIx::Regexp::Token::CharClass::POSIX::Unknown>,
 and are considered a parse failure.
 
 =head1 METHODS
@@ -42,7 +43,7 @@ use base qw{ PPIx::Regexp::Token::CharClass };
 
 use PPIx::Regexp::Constant qw{ COOKIE_CLASS MINIMUM_PERL };
 
-our $VERSION = '0.021_11';
+our $VERSION = '0.028_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -108,7 +109,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
