@@ -39,7 +39,7 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.021_11';
+our $VERSION = '0.028_01';
 
 ##=head2 is_case_sensitive
 ##
@@ -82,7 +82,7 @@ our $VERSION = '0.021_11';
     sub _is_case_sensitive {
 	my ( $self ) = @_;
 	my $content = $self->content();
-	$content =~ m/ \A \\ p { ( .* ) } /smxi
+	$content =~ m/ \A \\ p [{] ( .* ) [}] /smxi
 	    or return 0;
 	$content = lc $1;
 	$content =~ s/ \A ^ //smx;
@@ -176,7 +176,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
