@@ -34,7 +34,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.021_11';
+our $VERSION = '0.028_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -43,14 +43,18 @@ sub perl_version_introduced {
     return '5.009005';
 }
 
+my %matcher = (
+    q{?}	=> qr{ \A \\ \? \| }smx,
+    q{|}	=> qr{ \A \? \\ \| }smx,
+);
+
 sub __PPIX_TOKENIZER__regexp {
     my ( $class, $tokenizer, $character ) = @_;
 
-    # The actual expression being matched it \A \? \|. The extra
-    # optional escapes are because any of the non-open-bracket
-    # punctuation characters may also be the delimiter.
-    if ( my $accept = $tokenizer->find_regexp(
-	    qr{ \A \\? \? \\? \| }smx ) ) {
+    my $re = $matcher{ $tokenizer->get_start_delimiter() } ||
+	qr{ \A \? \| }smx;
+
+    if ( my $accept = $tokenizer->find_regexp( $re ) ) {
 	return $accept;
     }
 
@@ -72,7 +76,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
