@@ -19,7 +19,7 @@ C<PPIx::Regexp::Token::Whitespace> has no descendants.
 
 This class represents whitespace. It will appear inside the regular
 expression only if the /x modifier is present, but it may also appear
-between the type and the opening delimiter (e.g. C<qr {foo}> or after
+between the type and the opening delimiter (e.g. C<qr {foo}>) or after
 the regular expression in a bracketed substitution (e.g. C<s{foo}
 {bar}>).
 
@@ -37,7 +37,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.021_11';
+our $VERSION = '0.028_01';
 
 sub significant {
     return;
@@ -83,7 +83,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
