@@ -42,7 +42,7 @@ use PPIx::Regexp::Token::Whitespace		();
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.021_11';
+our $VERSION = '0.028_01';
 
 {
     # Names of classes containing tokenization machinery. There are few
@@ -192,7 +192,11 @@ our $VERSION = '0.021_11';
 
 	$self->{content} = $self->decode( $self->{content} );
 
-	$self->{cursor_limit} = length $self->{content};
+	if ( $self->{content} =~ m/ \s+ \z /smx ) {
+	    $self->{cursor_limit} = $-[0];
+	} else {
+	    $self->{cursor_limit} = length $self->{content};
+	}
 
 	$self->{trace}
 	    and warn "\ntokenizing '$self->{content}'\n";
@@ -330,6 +334,11 @@ sub find_regexp {
     return wantarray ? ( $-[0] + 0, $+[0] + 0 ) : $+[0] + 0;
 }
 
+sub get_start_delimiter {
+    my ( $self ) = @_;
+    return $self->{delimiter_start};
+}
+
 sub get_token {
     my ( $self ) = @_;
 
@@ -373,7 +382,7 @@ sub make_token {
 	and warn "make_token( $length, '$class' ) => '$content'\n";
     $self->{trace} > 1
 	and warn "    make_token: cursor_curr = $self->{cursor_curr}; ",
-    "cursor_limit = $self->{cursor_limit}\n";
+	    "cursor_limit = $self->{cursor_limit}\n";
     my $token = $class->_new( $content ) or return;
     $token->significant() and $self->{expect} = undef;
     $token->__PPIX_TOKEN__post_make( $self, $arg );
@@ -525,15 +534,22 @@ sub __PPIX_TOKENIZER__init {
     my ( $class, $tokenizer, $character ) = @_;
 
     $tokenizer->{mode} = 'kaput';
-    $tokenizer->{content} =~ m/ \A ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
+    $tokenizer->{content} =~ m/ \A \s* ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
 	or return $tokenizer->make_token(
 	    length( $tokenizer->{content} ), TOKEN_UNKNOWN );
 #   my ( $type, $white, $delim ) = ( $1, $2, $3 );
     my ( $type, $white ) = ( $1, $2 );
+    my $start_pos = defined $-[1] ? $-[1] :
+	defined $-[2] ? $-[2] :
+	defined $-[3] ? $-[3] : 0;
+
     defined $type or $type = '';
     $tokenizer->{type} = $type;
 
     my @tokens;
+    $start_pos
+	and push @tokens, $tokenizer->make_token( $start_pos,
+	'PPIx::Regexp::Token::Whitespace' );
     push @tokens, $tokenizer->make_token( length $type,
 	'PPIx::Regexp::Token::Structure' );
     length $white > 0
@@ -651,10 +667,22 @@ sub __PPIX_TOKENIZER__finish {
 
 	# We are out of string. Make the modifier token and close up
 	# shop.
-	$tokenizer->{cursor_limit} = length $tokenizer->{content};
+	my $trailer;
+	if ( $tokenizer->{content} =~ m/ \s+ \z /smx ) {
+	    $tokenizer->{cursor_limit} = $-[0];
+	    $trailer = length( $tokenizer->{content} ) -
+		$tokenizer->{cursor_curr};
+	} else {
+	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
+	}
 	push @tokens, $tokenizer->make_token(
 	    $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
 	    'PPIx::Regexp::Token::Modifier' );
+	if ( $trailer ) {
+	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
+	    push @tokens, $tokenizer->make_token(
+		$trailer, 'PPIx::Regexp::Token::Whitespace' );
+	}
 	$tokenizer->{mode} = 'kaput';
 
     } else {
@@ -965,6 +993,13 @@ This method returns the offset from the current position in the content
 string to the matching delimiter (which will always be positive), or
 undef if no match can be found.
 
+=head2 get_start_delimiter
+
+ my $start_delimiter = $tokenizer->get_start_delimiter();
+
+This method is used by tokenizers to access the start delimiter for the
+regular expression.
+
 =head2 get_token
 
  my $token = $tokenizer->make_token( 3 );
@@ -1103,7 +1138,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
